# last modified 2022-10-27

if (getRversion() >= '2.15.1') globalVariables(c('.dfbeta', '.mfrow', '.dfbetas',
    'top', 'tiesVariable', 'robustVariable', 'subsetVariable', 'rhsVariable',
    'tiesFrame', 'robustFrame', 'xBox', 'outerOperatorsFrame', 'operatorsFrame',
    'formulaFrame', 'subsetFrame', 'buttonsFrame', 'rhsEntry', '.CoxZPH', '.b',
    '.residuals', '.X', '.fitted', '.tab.1.1', 'confintVariable', '.newdata',
    'confintFrame', 'typeFrame', 'typeVariable', 'errorVariable', 'survtypeVariable',
    'detailVariable', 'conftypeVariable', 'plotconfVariable', '.Survfit',
    'survtypeFrame', 'detailFrame', 'conftypeFrame', 'plotconfFrame', 'errorFrame',
    'factorsButton', 'allButton', 'clusterButtonsFrame', 'newVar',
    'distributionVariable', 'distributionFrame', 'dataTab', 'optionsTab', 
    'modelTab', 'notebook', 'termsPlotFrame', 'termsPlotVariable', 'termsTestFrame', 
    'termsTestVariable'))